searchNodes=[{"doc":"Documentation for ExGtin. This library provides functionality for validating GTIN compliant codes.","ref":"ExGtin.html","title":"ExGtin","type":"module"},{"doc":"Generates valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesReturns code with check digitExamplesiex&gt; ExGtin.generate(&quot;629104150021&quot;) {:ok, &quot;6291041500213&quot;} iex&gt; ExGtin.generate(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}","ref":"ExGtin.html#generate/1","title":"ExGtin.generate/1","type":"function"},{"doc":"Generates valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesThrows Argument Exception if there was an errorExamplesiex&gt; ExGtin.generate!(&quot;629104150021&quot;) &quot;6291041500213&quot; iex&gt; ExGtin.generate(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}","ref":"ExGtin.html#generate!/1","title":"ExGtin.generate!/1","type":"function"},{"doc":"Find the GS1 prefix country for a GTIN numberReturns {atom, String.t()}Examplesiex&gt; ExGtin.gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;} iex&gt; ExGtin.gs1_prefix_country(&quot;6291041500214&quot;) {:ok, &quot;GS1 Emirates&quot;} iex&gt; ExGtin.gs1_prefix_country(&quot;9541041500214&quot;) {:error, &quot;No GS1 prefix found&quot;}","ref":"ExGtin.html#gs1_prefix_country/1","title":"ExGtin.gs1_prefix_country/1","type":"function"},{"doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesReturns {:ok, &quot;GTIN-#&quot;} or {:error}Examplesiex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.validate(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;}","ref":"ExGtin.html#validate/1","title":"ExGtin.validate/1","type":"function"},{"doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesThrows ArgumentError if an error occursExamplesiex&gt; ExGtin.validate!(&quot;6291041500213&quot;) &quot;GTIN-13&quot;","ref":"ExGtin.html#validate!/1","title":"ExGtin.validate!/1","type":"function"},{"doc":"Documentation for ExGtin. This library provides functionality for validating GTIN compliant codes.","ref":"ExGtin.Validation.html","title":"ExGtin.Validation","type":"module"},{"doc":"Checks the code for the proper length as specified by the GTIN-8,12,13,14 specificationReturns {atom, String.t()}Examplesiex&gt; ExGtin.Validation.check_code_length([1,2,3,4,5,6,7,8]) {:ok, &quot;GTIN-8&quot;} iex&gt; ExGtin.Validation.check_code_length([1,2,3,4,5,6,7]) {:error, &quot;Invalid GTIN Code Length&quot;}","ref":"ExGtin.Validation.html#check_code_length/1","title":"ExGtin.Validation.check_code_length/1","type":"function"},{"doc":"Find the GS1 prefix country for a GTIN numberReturns {atom, String.t()}Examplesiex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;} iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;6291041500214&quot;) {:ok, &quot;GS1 Emirates&quot;} iex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;9541041500214&quot;) {:error, &quot;No GS1 prefix found&quot;}","ref":"ExGtin.Validation.html#find_gs1_prefix_country/1","title":"ExGtin.Validation.find_gs1_prefix_country/1","type":"function"},{"doc":"When generating the code, checks the code for the proper length as specified by the GTIN-8,12,13,14 specification. The code should be -1 the length of the GTIN code as the check digit will be added laterReturns {atom, String.t()}Examplesiex&gt; ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6,7]) {:ok, &quot;GTIN-8&quot;} iex&gt; ExGtin.Validation.generate_check_code_length([1,2,3,4,5,6]) {:error, &quot;Invalid GTIN Code Length&quot;}","ref":"ExGtin.Validation.html#generate_check_code_length/1","title":"ExGtin.Validation.generate_check_code_length/1","type":"function"},{"doc":"Generate check digit GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesReturns numberExamplesiex&gt; ExGtin.Validation.generate_check_digit([6,2,9,1,0,4,1,5,0,0,2,1]) 3","ref":"ExGtin.Validation.html#generate_check_digit/1","title":"ExGtin.Validation.generate_check_digit/1","type":"function"},{"doc":"Generate valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesReturns {atom, String.t()}Examplesiex&gt; ExGtin.Validation.generate_gtin_code(&quot;629104150021&quot;) {:ok, &quot;6291041500213&quot;} iex&gt; ExGtin.Validation.generate_gtin_code(&quot;62921&quot;) {:error, &quot;Invalid GTIN Code Length&quot;}","ref":"ExGtin.Validation.html#generate_gtin_code/1","title":"ExGtin.Validation.generate_gtin_code/1","type":"function"},{"doc":"Check for valid GTIN-8, GTIN-12, GTIN-13, GTIN-14, GSIN, SSCC codesReturns {atom, String.t()}Examplesiex&gt; ExGtin.Validation.gtin_check_digit(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.Validation.gtin_check_digit(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;}","ref":"ExGtin.Validation.html#gtin_check_digit/1","title":"ExGtin.Validation.gtin_check_digit/1","type":"function"},{"doc":"Looks up the GS1 prefix in a table GS1 Reference https://www.gs1.org/company-prefixReturns {atom, String.t()}","ref":"ExGtin.Validation.html#lookup_gs1_prefix/1","title":"ExGtin.Validation.lookup_gs1_prefix/1","type":"function"},{"doc":"By index, returns the corresponding value to multiply the digit byReturns numberExamplesiex&gt; ExGtin.Validation.mult_by_index_code(1) 1 iex&gt; ExGtin.Validation.mult_by_index_code(2) 3","ref":"ExGtin.Validation.html#mult_by_index_code/1","title":"ExGtin.Validation.mult_by_index_code/1","type":"function"},{"doc":"Calculates the sum of the digits in a string and multiplied value based on index orderReturns numberExamplesiex&gt; ExGtin.Validation.multiply_and_sum_array([6,2,9,1,0,4,1,5,0,0,2,1]) 57","ref":"ExGtin.Validation.html#multiply_and_sum_array/1","title":"ExGtin.Validation.multiply_and_sum_array/1","type":"function"},{"doc":"Calculates the difference of the highest rounded multiple of 10Returns numberExamplesiex&gt; ExGtin.Validation.subtract_from_nearest_multiple_of_ten(57) 3","ref":"ExGtin.Validation.html#subtract_from_nearest_multiple_of_ten/1","title":"ExGtin.Validation.subtract_from_nearest_multiple_of_ten/1","type":"function"},{"doc":"ExGtin A GTIN (Global Trade Item Number) &amp; UPC (Universal Price Code) Generation and Validation Library in Elixir under the GS1 specification.GTIN-12 (UPC-A): this is a 12-digit number used primarily in North AmericaGTIN-8 (EAN/UCC-8): this is an 8-digit number used predominately outside of North AmericaGTIN-13 (EAN/UCC-13): this is a 13-digit number used predominately outside of North AmericaGTIN-14 (EAN/UCC-14 or ITF-14): this is a 14-digit number used to identify trade items at various packaging levels","ref":"readme.html","title":"ExGtin","type":"extras"},{"doc":"Supports GTIN-8, GTIN-12 (UPC-12), GTIN-13 (GLN), GTIN-14, GSIN, SSCC codesGenerate GTINCheck GTIN validityLookup GS1 country prefix","ref":"readme.html#features","title":"ExGtin - Features","type":"extras"},{"doc":"WARNING 1.0.0 contains breaking changes from 0.4.0Add :ex_gtin as a dependency to your project's mix.exs:def deps do [{:ex_gtin, &quot;~&gt; 1.0.1&quot;}] endand run mix deps.get to install the :ex_gtin dependencymix deps.get","ref":"readme.html#installation","title":"ExGtin - Installation","type":"extras"},{"doc":"Check GTIN codesiex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;} iex&gt; ExGtin.validate(&quot;6291041500214&quot;) {:error, &quot;Invalid Code&quot;} ex&gt; ExGtin.validate!(&quot;6291041500213&quot;) &quot;GTIN-13&quot;Pass GTIN numbers in as a String, Number or an Arrayiex&gt; number = [6, 2, 9, 1, 0, 4, 1, 5, 0, 0, 2, 1,3] iex&gt; ExGtin.validate(number) {:ok, &quot;GTIN-13&quot;} iex&gt; number = 6_291_041_500_213 iex&gt; ExGtin.validate(number) {:ok, &quot;GTIN-13&quot;}Generate GTIN codesiex&gt; ExGtin.generate(&quot;629104150021&quot;) {:ok, &quot;6291041500213&quot;} iex&gt; ExGtin.generate!(&quot;629104150021&quot;) &quot;6291041500213&quot;Lookup GS1 Prefixiex&gt; ExGtin.Validation.find_gs1_prefix_country(&quot;53523235&quot;) {:ok, &quot;GS1 Malta&quot;}Using Strings, Arrays or NumbersStringiex&gt; ExGtin.validate(&quot;6291041500213&quot;) {:ok, &quot;GTIN-13&quot;}Array of Integersiex&gt; ExGtin.validate([6, 2, 9, 1, 0, 4, 1, 5, 0, 0, 2, 1, 3]) {:ok, &quot;GTIN-13&quot;}Integer kiex&gt; ExGtin.validate(6291041500213) {:ok, &quot;GTIN-13&quot;}Integers with leading zeros may not process properly","ref":"readme.html#usage","title":"ExGtin - Usage","type":"extras"},{"doc":"GTINHow to calculate GTINDocumentation can be found at https://hexdocs.pm/ex_gtin on HexDocs.","ref":"readme.html#reference","title":"ExGtin - Reference","type":"extras"},{"doc":"Run tests withmix testRun test coverageMIX_ENV=test mix coveralls","ref":"readme.html#tests","title":"ExGtin - Tests","type":"extras"},{"doc":"Please read CONTRIBUTING.md for details on our code of conduct, and the process for submitting pull requests to us.When making pull requests, please be sure to update the CHANGELOG.md with the corresponding changes. Please make sure that all tests pass, add tests for new functionality and that the static analysis checker credo is run. Use mix pull_request_checkout.task to ensure that everything checks out.Run static code analysismix credoGenerate Docsmix docsRun the gambit of tests, static analysis and coveragemix pull_request_checkout.task","ref":"readme.html#contributing","title":"ExGtin - Contributing","type":"extras"},{"doc":"This project is sponsored by KickinEspresso","ref":"readme.html#sponsors","title":"ExGtin - Sponsors","type":"extras"},{"doc":"We use SemVer for versioning. For the versions available, see the tags on this repository.","ref":"readme.html#versioning","title":"ExGtin - Versioning","type":"extras"},{"doc":"Please refer to the Code of Conduct for details","ref":"readme.html#code-of-conduct","title":"ExGtin - Code of Conduct","type":"extras"},{"doc":"Please refer to the Security for details","ref":"readme.html#security","title":"ExGtin - Security","type":"extras"},{"doc":"This project is licensed under the MIT License - see the LICENSE.md file for details","ref":"readme.html#license","title":"ExGtin - License","type":"extras"},{"doc":"mix hex.publish","ref":"readme.html#publish-releasing","title":"ExGtin - Publish &amp; Releasing","type":"extras"}]